decode

Function decode 

pub fn decode(
    src: &[u8],
    _profile: &Profile,
    canceled: &AtomicBool,
) -> Result<DecodedImage, DecodeError>
Decodes a JPEG stream to BGRA8 output.

Errors

Returns DecodeError::BufferTooShort if the input is shorter than the SOI marker. Returns DecodeError::InvalidFormat if the input is not a valid JPEG stream. Returns DecodeError::Jpeg if the underlying JPEG decoder fails.